@@ -205,7 +205,7 @@ def dump(data, stream, sort_keys=True, indent=0):
             dump(i, stream, sort_keys, indent + 1)
     elif isinstance(data, dict):
         it = data.items()
-        if sort:
+        if sort_keys:
             it = sorted(it)
         for k, v in it:
             do_indent(indent)
